@@ -161,9 +161,8 @@ trans_network <- R6Class(classname = "trans_network",
 			usename_rawtaxa_when_taxalevel_notOTU = FALSE,
 			...
 			){
-			if(!require(igraph)){
-				stop("igraph package not installed")
-			}
+			private$check_igraph()
+			
 			sampleinfo <- self$use_sampleinfo
 			taxa_level <- self$taxa_level
 			taxa_table <- self$use_tax
@@ -299,6 +298,7 @@ trans_network <- R6Class(classname = "trans_network",
 		#' t1$cal_module()
 		#' }
 		cal_module = function(method = "cluster_fast_greedy", module_name_prefix = "M"){
+			private$check_igraph()
 			# add modules
 			network <- self$res_network
 			if(!is.character(method)){
@@ -326,6 +326,7 @@ trans_network <- R6Class(classname = "trans_network",
 			if(!require(rgexf)){
 				stop("Please install rgexf package")
 			}
+			private$check_igraph()
 			private$saveAsGEXF(network = self$res_network, filepath = filepath)
 		},
 		#' @description
@@ -337,18 +338,22 @@ trans_network <- R6Class(classname = "trans_network",
 		#' t1$cal_network_attr()
 		#' }
 		cal_network_attr = function(){
+			private$check_igraph()
 			self$res_network_attr <- private$network_attribute(self$res_network)
 			message('Result is stored in object$res_network_attr ...')
 		},
 		#' @description
 		#' Calculate node properties.
 		#'
+		#' Authors: Chi Liu, Umer Zeeshan Ijaz
+		#'
 		#' @return res_node_type in object.
 		#' @examples
 		#' \donttest{
 		#' t1$cal_node_type()
 		#' }
 		cal_node_type = function(){
+			private$check_igraph()
 			network <- self$res_network
 			node_type <- private$module_roles(network)
 			use_abund <- self$use_abund
@@ -360,7 +365,7 @@ trans_network <- R6Class(classname = "trans_network",
 			}else{
 				node_type <- cbind.data.frame(node_type, self$use_tax[rownames(node_type), ])
 			}
-			node_type$degree <- degree(network)[rownames(node_type)]
+			node_type$degree <- igraph::degree(network)[rownames(node_type)]
 			node_type$betweenness <- betweenness(network)[rownames(node_type)]
 			# Add abundance info
 			sum_abund <- apply(use_abund, 2, function(x) sum(x) * 100/sum(use_abund))
@@ -383,6 +388,7 @@ trans_network <- R6Class(classname = "trans_network",
 		#' t1$cal_eigen()
 		#' }
 		cal_eigen = function(){
+			private$check_igraph()
 			use_abund <- self$use_abund
 			res_node_type <- self$res_node_type
 			# calculate eigengene for each module
@@ -475,6 +481,7 @@ trans_network <- R6Class(classname = "trans_network",
 		#' # return a sub network that contains all nodes of module M1
 		#' }
 		subset_network = function(node = NULL, edge = NULL, rm_single = TRUE){
+			private$check_igraph()
 			network <- self$res_network
 			if(!is.null(node)){
 				nodes_raw <- V(network)$name
@@ -508,6 +515,7 @@ trans_network <- R6Class(classname = "trans_network",
 		#' t1$get_edge_table()
 		#' }
 		get_edge_table = function(){
+			private$check_igraph()
 			network <- self$res_network
 			edges <- t(sapply(1:ecount(network), function(x) ends(network, x)))
 			edge_label <- E(network)$label
@@ -532,7 +540,7 @@ trans_network <- R6Class(classname = "trans_network",
 		#' }
 		cal_powerlaw_p = function(...){
 			network <- self$res_network
-			degree_dis <- degree(network)
+			degree_dis <- igraph::degree(network)
 			if(!require(poweRlaw)){
 				stop("Please first install poweRlaw package from CRAN !")
 			}
@@ -556,8 +564,9 @@ trans_network <- R6Class(classname = "trans_network",
 		#' t1$cal_powerlaw_fit()
 		#' }
 		cal_powerlaw_fit = function(xmin = NULL, ...){
+			private$check_igraph()
 			network <- self$res_network
-			degree_dis <- degree(network, mode="in")
+			degree_dis <- igraph::degree(network, mode="in")
 			self$res_powerlaw_fit <- fit_power_law(degree_dis + 1, xmin = xmin, ...)
 			message('Powerlaw fitting result is stored in object$res_powerlaw_fit ...')
 		},
@@ -587,6 +596,11 @@ trans_network <- R6Class(classname = "trans_network",
 		}
 		),
 	private = list(
+		check_igraph = function(){
+			if(!require(igraph)){
+				stop("Please first install igraph package!")
+			}
+		},
 		cal_corr = function(inputtable, cor_method) {
 			N <- ncol(inputtable)
 			use_names <- colnames(inputtable)
@@ -659,12 +673,12 @@ trans_network <- R6Class(classname = "trans_network",
 			res <- data.frame(
 				Vertex = round(vcount(x), 0), 
 				Edge = round(ecount(x), 0), 
-				Average_degree = sum(degree(x))/length(degree(x)), 
+				Average_degree = sum(igraph::degree(x))/length(igraph::degree(x)), 
 				Average_path_length = average.path.length(x), 
 				Network_diameter = round(diameter(x, directed = FALSE), 0), 
 				Clustering_coefficient = transitivity(x), 
 				Density = graph.density(x), 
-				Heterogeneity = sd(degree(x))/mean(degree(x)), 
+				Heterogeneity = sd(igraph::degree(x))/mean(igraph::degree(x)), 
 				Centralization = centr_degree(x)$centralization
 				)
 			res <- base::as.data.frame(t(res))
@@ -673,8 +687,8 @@ trans_network <- R6Class(classname = "trans_network",
 		},
 		# modified based on microbiomeSeq (http://www.github.com/umerijaz/microbiomeSeq) 
 		module_roles = function(comm_graph){
-			require(igraph)
-			td <- degree(comm_graph) %>% data.frame(taxa = names(.), total_links = ., stringsAsFactors = FALSE)
+			
+			td <- igraph::degree(comm_graph) %>% data.frame(taxa = names(.), total_links = ., stringsAsFactors = FALSE)
 			wmd <- private$within_module_degree(comm_graph)
 			z <- private$zscore(wmd)
 			# NaN may generate in Zi for modules with very few nodes
@@ -706,7 +720,7 @@ trans_network <- R6Class(classname = "trans_network",
 						}
 					})))
 				g3 <- induced.subgraph(graph = comm_graph, vids = neighverts)
-				mod_degree <- degree(g3)
+				mod_degree <- igraph::degree(g3)
 				for(i in mod_nodes){
 					ki <- mod_degree[which(names(mod_degree) == i)]
 					tmp <- data.frame(module = mod, taxa = names(ki), mod_links = ki)
